@@ -4,11 +4,11 @@ from .advjson import AdvJSONFormat
 
 __package__ = "pyLogFormats"
 __author__ = "Matt Limb <matt.limb17@gmail.com>"
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 
 __all__ = [
     "BunyanFormat",
-    "JSONFormt",
+    "JSONFormat",
     "AdvJSONFormat"
 ]
\ No newline at end of file
