@@ -8,12 +8,15 @@ BASELINE = vars(logging.LogRecord(*[None for _ in range(9)]))
 class BunyanFormat(logging.Formatter):
     """ A Simple Bunyan JSON Format """
     def format(self, record):
+
+        formatted_message = getattr(record, "msg") % getattr(record, "args", tuple())
+
         fr = dict(
             time=datetime.fromtimestamp(getattr(record, "created")).strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z",
             name=getattr(record, "name"),
             pid=getattr(record, "process"),
             level=getattr(record, "levelno"),
-            msg=getattr(record, "msg"),
+            msg=formatted_message,
             hostname=platform.node(),
             v=0
         )
